@@ -47,7 +47,17 @@ EOAPI Eina_Bool efl_config_set(Eo *obj, const char *name, const Eina_Value *valu
  *
  * @ingroup Efl_Config
  */
-EOAPI Eina_Value *efl_config_get(const Eo *obj, const char *name) EFL_TRANSFER_OWNERSHIP;
+EOAPI Eina_Value *efl_config_get(const Eo *obj, const char *name) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+
+EWAPI extern const Efl_Event_Description _EFL_CONFIG_EVENT_CONFIG_CHANGED;
+
+/** Called when a config value has been changed for the manager object. Passed
+ * string is the name of the value or NULL if all values were changed.
+ * @return const char *
+ *
+ * @ingroup Efl_Config
+ */
+#define EFL_CONFIG_EVENT_CONFIG_CHANGED (&(_EFL_CONFIG_EVENT_CONFIG_CHANGED))
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
