@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Flip_Part;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl UI flip internal class
  *
  * @ingroup Efl_Ui_Flip_Part
@@ -20,5 +21,6 @@ typedef Eo Efl_Ui_Flip_Part;
 #define EFL_UI_FLIP_PART_CLASS efl_ui_flip_part_class_get()
 
 EWAPI const Efl_Class *efl_ui_flip_part_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
