@@ -13,31 +13,18 @@ typedef Eo Efl_Ui_Layout_Part_Table;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Represents a Table created as part of a layout.
  *
  * Cannot be deleted. This is only a representation of an internal object of an
  * EFL layout.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Layout_Part_Table
  */
 #define EFL_UI_LAYOUT_PART_TABLE_CLASS efl_ui_layout_part_table_class_get()
 
 EWAPI const Efl_Class *efl_ui_layout_part_table_class_get(void);
 
-#ifdef EFL_UI_LAYOUT_PART_TABLE_PROTECTED
-/**
- * @brief Real part property
- *
- * @param[in] obj The object.
- * @param[in] layout Real part object
- * @param[in] part Real part name
- *
- * @ingroup Efl_Ui_Layout_Part_Table
- */
-EOAPI void efl_ui_layout_part_table_real_part_set(Eo *obj, Efl_Object *layout, const char *part);
-#endif
-#endif /* EFL_BETA_API_SUPPORT */
-
 #endif
